%% For a matrix of (x,y) or (x,y,z) coordinates, 
%% returns a column of distances along the path.
%% ---------------------------------------------------------------------
%% Parameters:
%%	xyz - column of 1, 2, 3, or any dimensional coordinates
%%
%%  Returns:
%%	dist - column of cumulative distances from the first point to each of the points 
%%		of the path ( 0.0 at the first point)
%%	spacing - column of spacings between the corresponding point in xyz 
%%		and the preceding point( 0.0 at the first point)
%% ==============================================================================

function [ dist, spacing ] = distance_path( xyz )

	n = size(xyz,1);

	spacing = zeros(n,1);		% initialize outputs
	dist = spacing;

	for j=2:n
		j1 = j - 1;

		d = xyz(j,:)-xyz(j1,:);

		s = sqrt(sum(d.*d,2));

		spacing(j,1) = s;
		dist(j,1) = dist(j1,1) + s;
	end
end

