%% Sets in global structure 'procdata' default parameters suitable for most projects 
%% ==================================================================================

function procdata_default()

global procdata modes

modes = [];			% no modes in processing

procdata.dataset = 'ffid';	% dataset order (can also use 'id' or 'cmp' in the future)
				% looks like this is duplicated by procdata.data_order?

procdata.data_order = 'ffid';	% order in which data are retrieved
				% in some programs like dispersion picking, 'cmp' data order can be used

procdata.location_id = 'id';	% name of the field used to selecting records for plotting
				% 'id' means pick.id is used
				% 'number', ;ffid', or 'cmp' means generic pick.number (ffid or cmp) is used

procdata.print_jpeg = true;	% flag to allow making jpeg outputs of figures
procdata.print_vintage = false;	% flag to include vintage number in jpeg (image) file names 
procdata.vint_list = [];	% list of vintages; used internally 

procdata.plot_panels = 3;	% number of panels to plot in edit_ffid

procdata.rec_quantity = "Ground velocity";	% name of recorded quantity (for plots) 
procdata.unit_distance = "m";
procdata.plot_chan_increment = 2;

procdata.progress_indicator = true;	% enables display of progress indicator in interactive programs

%% time picking

procdata.pick_source_time = "";	% do not auto-pick source time from near-source first breaks
				% other values are: "near" (from near trace), "aux" (from aux trace)

procdata.pick_fb.pick_source_mode = 'maxamp';	% mode for selecting traces to pick source time
						% 'mintime' - using traces with smallest times
						% 'maxamp' - using traces with largest first-break amplitudes
						% 'minoffset' - using traces with smallest offset


	% shifts of time picks in selected FFIDs in which auto-picking picked later bounces
	% Columns of this matrix are FFID values which to correct and time shifts (ms):

procdata.time_shift = [];	

procdata.time_start = -20;	% record time output as time = 0 in SEGY
				% (i.e., the record in SEGY file will be shifted 
				% by (-procdata.time_start) ms 

procdata.pick_fb.method = 'stalta';	% this can also be 'maxamp' for simple amplitude maxima
procdata.pick_fb.stalta_min = 2.0;
procdata.pick_fb.stalta_threshold = 0.95;

procdata.pick_fb.t_peak = 15.0;		% STA time window after picked first break
procdata.pick_fb.t_prepeak = 50.0;	% LTA time window before picked first break

procdata.pick_fb.near_trc = 1;		% number of nearest traces to estimate source time
 					% (if value <=0 here, do not estimate source time)

procdata.pick_fb.near_chan = [];	% range of channels to estimate source time 
					% (used in cojunction with near_trc above)
					% [] means no restriction on channel numbers

procdata.record_length = 1000;	% output record length in ms

procdata.drop_ffid = [];	% do not drop anything this time
procdata.drop_chan = []; 

procdata.line = 0;		% line number is not used but must be given
procdata.vintage = [];		% empty [] or negative values mean any vintage will be accepted
				% vintage = 0 would mean acceptable (baseline) vintage
				% vintage < 0 would mean any vintage
 
procdata.id = [];		% list for selecting data by location ID

procdata.plot = true;		% flag to use interactive plot in proc_edit or proc_spectra, etc.

procdata.plot_suffix = "";	% optinal suffix for plot file names

procdata.plot_XY_range = [];	% plotting the default XY range
procdata.plot_Z_range = [];	% plotting the default Z (depth) range
procdata.plot_V_range = [];	% plotting the default V (velocity) range
procdata.plot_time_range = [];	% plotting the entire extracted time range
procdata.plot_slwns_range = [];	% no control of plotting slowness range
procdata.plot_freq_range = [];	% no control of plotting frequency range
procdata.plot_kx_range = [];	% no control of plotting horizontal wavenumber 
procdata.plot_colorbar_range = [];	% no control on plotting colorbars 
procdata.plot_contour = [];		% no control on contour levels 
					% (this array can be one integer value for the number of contours
					% or multiple values for specific contour levels)

procdata.plot_chan_increment = 2;	% increment for labeling channels in t-x plots

procdata.plot_grid_on = true;	% flag to show grids on plots in edit_ffid

procdata.subplots = [];		% with [] here, plotting is done into one plot. Otherwise, if a row
				% of this matrix is [ ID_min, ID_max, subplot_rows, subplot_columns, subplot_no ]
				% then for data with 'id' value between ID_min and ID_max, 
				% plotting is done into a subplot given by command: 
				% subplot(subplot_rows, subplot_columns, subplot_no ) 

procdata.save = true;		% save edited data


%%%% options for proc_edit

procdata.src_chan_shift	= 0;		% shift in source numbers when keying them by nearest 'channel' 
					% numbers (only needed in Mark's geometry)

procdata.src_stn_correct = true;	% if this is 'true', source station numbers 
					% are changed to match the nearest receiver station. 
					% skid values are changed accordingly

procdata.offset_xyz = true;	% if true, using full 3-D source-rceiver distances, otherwise using 2-D

procdata.kill = [];		% list of channels to delete

%%%% options for proc_spectra

procdata.reduction_vel = 0.0;

procdata.chan_range = [ 1, 25; 26 48 ];	% ranges of channels for which spectra are plotted

%% select offset range. Only one offset range is used in dispersion analysis, multiple ranges
%% can be used in other programs.

procdata.offset_range = [ 1.0, 13.0; 5, 13 ];

%%%% options for proc_dispersion
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Phase velocity range for scanning:

procdata.phase_vel = [ 0.05, 3.0 ];

%% Expected velocity (basically, the lowest velocity you want to see).
%% The largest frequency of measurement will be set
%% below the Nyquist frequency of spatial sampling for waves at this velocity

procdata.phase_vel_expected = 0.1;	

%% midpoint range factor (number of wavelengths covered at each frequency; should be >= 0):

procdata.offset_range_N = 0;

%% minimum frequency for picking semblance peaks

procdata.freq_min = 0.006;


%% create a line in (frequency,slowness) plane separating the fundamental
%% mode from the strong higher mode seen in the data.
%% If values of this array are s(i), then the empirical separator line is:
%	slowness(f) = s(2) - s(3)/(frequency - s(1))

procdata.mode_separ = [ 0.035, 8.0, 0.1 ];

% CMP profile coordinates at which to extract dispersion spectra

procdata.cmp_loc = 1:1:20;	

%%%% options for proc_invert
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

procdata.default_model = 'interp/default_model.txt'; % name of file with initial model
						% for interactive inversion

% you can also use numeric array of [line_no, vintage, ID ] from a previously built model.
% In this case, the starting model will be taken from .mat file for that line number, vintage,
% and location ID. This selection supersedes procdata.default_model

% Example: procdata.starting_model = [15,0,1]; 	

procdata.starting_model = [];	% no starting model by default

procdata.standard_model = {};	% name of function returning standard models available
				% in pick_model(), and its options (strings)

procdata.pseudodepth = 0.5;	% factor converting horizontal wavelength to pseudodepth 

procdata.Vs = 1.11;		% factor converting phase velocity to S-wave velocity

% plotting modes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

procdata.plot_aux = false;	% flag to create auxiliary figure 777 and similar	

procdata.plot_vel = [];		% no velocity lines plotted

procdata.plot_modes = 'fs';	% mode plots in (frequency,slowness) format
				% other options: 'fv' (frequency,V)), 'zvs' (pseudo-depth,Vs)

procdata.plot_modes_num = 6;	% maximum number of modes to plot
procdata.plot_modes_ids = true;	% flag to plot mode id (such as FFID number) near every mode line

procdata.plot_modes_uz = [];	% plot vertical displacements in modes for selected wavelengths
				% if this field is not empty, it is interpreted as:
				% plot_modes_uz = [ figure_number, wavelength_1, wavelength_2, ... ]
				% Real and imaginary parts of displacements for each wavelength are shown
				% in subplots of figure 'figure_number' 

% grid of velocities for CMP section plots
 
procdata.plot_disp_v = 0.07:0.005:0.12;	

procdata.plot_disp_freq_range = [0.02, 0.15];	% frequency range for dispersion plot (should be > 0)
procdata.plot_disp_lambda_range = [];		% if this array is not empty, it is used to restrict the
						% range of lambda (wavelength) values in CMP dispersion calculations

procdata.plot_Xtick_inc = [];	% if not empty, forced tick increment in X axis
procdata.plot_Ytick_inc = [];	% if not empty, forced tick increment in Y axis

% if you change the following variable to 'stop', proc_ffids() will return without doing any processing

procdata.run_status = 'run';

% miscellaneous plot formatting options
% ==============================================================================================

procdata.contour_line.color = 'black';		% line style for contour lines
procdata.contour_line.width = 1;

procdata.contour_label.x = 0.25;		% relative position of labels in contour lines (can be multiple)
procdata.contour_label.FontSize = 10;		% font size in points

end

