%% For a current set of basis functions in global 'bfun',
%% plots in current figure a section of depth distribution of the real part of 
%% the field
%%
%% Parameters:
%%	bf - the set of basis functions. This variable can be given in two ways:
%%		1) By a character string specifying the type of basis function required:
%%		'uz', 'ux' (for displacement components)
%%		'ezz' (or 'ez'), 'exz' (or 'ezx'), 'exx' (or 'ex') (strain components)
%%		'szz' (or 'sz'), 'sxz' (or 'szx'), 'sxx' (or 'sx') (stress components);
%%		2) directly by one of the 3-D matrices bfun.uz, bfun.ux, bfun.ezz, bfun.exx, etc.
%%	c - model vector, i.e. array of weights for each of the basis functions in 'bf'. For multiple
%%		entries in 'c', the corresponding records are plotted as a seismic section, with
%%		'c' values spanning the horizontal axis of the plot, and z plotted downward
%%	titl - optional string for plot title
%%	how - optional string indicating what to plot: 'real' (real part, in blue), 
%%		'imag' (in red), or 'complex' (both)
%%		(default is 'real')

function plot_field( bf, c, titl, how )

global model bfun

  if nargin < 3
	titl = '';
  end

  if nargin < 4
	how = 'real';
  end

  z = linspace(model.z0,model.z(end),400);	% depth grid for plotting

  % extract depth columns for each column in 'c'

  section = field_value( bf, c, z );

  % gain factor for plotting basis functions

  gain = 0.5;

  % plot

  hold on

  nc = size(section,2);

  for i=1:nc
	v = section(:,i)*gain;

%	v = v/(max(abs(v))+1.0e-8)*gain;	% normalize to peak value = 1

 % 	plot(v+i,z,'b-');

	if strcmpi(how,'imag') || strcmpi(how,'complex')
		plot(imag(v),z,'r-');
	end

	if strcmpi(how,'real') || strcmpi(how,'complex')
		plot(real(v),z,'b-');
	end
  end

  set(gca,"Ydir","reverse")
  %set(gca,"XTick",1:nc)
  grid on
  ylabel("z (m)")

  if ischar(bf)
  	xlabel(bf)
	title(['Field ' bf '; ' titl ])
  else
  	xlabel("column (c)")

  	title(titl)
  end
end

