%% Plots current model by smoothed magenta lines within each layer of the standard model
%%
%% Parameters:
%%	sm - handle of the standard model function 
%%		(this function is only used to obtain big groups of layers) 
%%	line_color - line color string to use
%%	zplot - optional depth parameter. If provided, plotting is only done for the segment
%%		containing depth z0
%% Returns:
%%	lh - list of graphics handles of the plotted line

function lh = plot_layered_model(sm, line_color, zplot)

global procdata model 

  lh = {};

  if isempty(sm) || ~strcmpi(procdata.plot_modes,'zvs')		% cannot plot
	return
  end

  z0 = 0.0;	% starting depth

  % starting from z, obtain standard models and plot as far as they extend to depth

  while z0 < model.z(end)

  	[ ~, lst, ind ] = sm(z0);

	if ~isempty(ind)
		zmax = model.z(ind(end));

		z = linspace(model.z(ind(1))-model.dz(ind(1)),zmax,20);	% points to plot the curves at
		
		vs = interp1(model.z(ind)-model.dz(ind)*0.5,model.vs(ind),z,'linear','extrap');

		plt = true;		% flag indicating that plotting is needed for this segment

		if nargin >= 3
			if zplot < model.z(ind(1)) - model.dz(ind(1)) || zplot > zmax
				plt = false;
			end
		end

		if plt
			lh{length(lh)+1} = line(vs,z,'LineStyle','-','Color',line_color);
		end

		if ind(end) == length(model.z)		% got to the bottom of model
			break
		end

		z0 = zmax + 0.1*model.dz(ind(end)+1);	% next layer
	else
		break

	end	% if ind

  end		% while

end

