%% Makes a 2-D plot of the layered model
%% Multiple vintages are plotted in a column of subplots
%%
%% Parameters:
%%	figno - figure number for the plot
%%	filename - name of file in directory interp/ to take the model from
%%	attr - name of the attribute (column) in the file to use: 'Gmax' or 'Vs' 
%%		(case-insensitive)
%%	axes_range	- optional range of plot coordinates

function plot_model_2D(figno,filename,attr,axes_range)

global procdata sett

	run('../config/settings.m')		% obtain settings in structure 'sett'

	data = load( [ 'interp/' filename ], '-ascii');

	% correct the data first. In lines containing Vs=0, replace the data
	% with those in the fiollowing lines

	ind = find(data(:,2)==0.0);

	if ~isempty(ind)
		data(ind,2:3) = data(ind+1,2:3);
	end

	% tests: replace values Gmax = x or Gmax = z and look at the plots

	%data(:,3) = data(:,4);
	%data(:,3) = data(:,6);

	% find vintages contained in this file

	vint = unique(data(:,1));

	nvint = length(vint);

	% select column in the data

	if strcmpi(attr,'gmax')
		datacol = 3;
	else
		datacol = 2;
	end

	% determine range of values common to all subplots

	if isempty(procdata.plot_colorbar_range)	% automatic range from data
		value_range = [ min(data(:,datacol)),max(data(:,datacol))];
	else
		value_range = procdata.plot_colorbar_range;
	end

	% define mesh for plotting

	xgrid = linspace(min(data(:,4)),max(data(:,4)),200);
	zgrid = linspace(min(data(:,6)),max(data(:,6)),20);

	figure(figno)
	clf
	set(gcf,'Position',sett.window_wide)

	% plot each vintage in a subplot

	for i=1:nvint

		subplot(nvint,1,i)

		plot_model_2D1(datacol,value_range,data(find(data(:,1)==vint(i)),:),xgrid,zgrid)

		set(gca,'YDir','reverse')

		if nargin>3
		  if length(axes_range) >= 4
			axis(axes_range);
		  elseif length(axes_range) >=2
			xlim(axes_range(1:2));
		  end
		end

		xlabel('X (m)','FontSize', 16)	% this sets axes label font sizes
		ylabel('Z (m)','FontSize', 16)

		set(gca,'FontSize', 12);	% this sets tick font size

		title(sprintf('%s in Vintage=%d', attr, vint(i)))
	end
end

