%% Helper for plot_model_2D(): Plots color image of model for one vintage
%%
%% Parameters:
%%	datacol - number iof column in data to plot
%%	value_range - two -element array specifying the range of values to show in color bar
%%			If value_range = [], teh range will be determined from data
%%	data - part of data table for one vintage extracted from .txt file
%%	xgrid,zgrid - mesh coordinates for plotting (initially a regular grid, 
%%			later corrected for surface topography)

function plot_model_2D1(datacol,value_range,data,xgrid,zgrid)

global procdata

	if isempty(data)	% nothing to do
		return
	end

	vint = data(1,1);	% vintage number

	surf_xz = load( sprintf('interp/surface_v%04d.txt',vint), '-ascii');	% load surface shape

	[X,Z] = meshgrid(xgrid,zgrid);

	V = zeros(size(X));	% grid of output values
%data
%X
%Z

	xc = unique(data(:,4));		% coordinates of data columns

	col = zeros(length(zgrid),length(xc));	% data columns

	for i=1:length(xc)
		d1 = data(find(data(:,4)==xc(i)),:);	% subset of data for the column

		% replace pairs of data at equal depths with averages

		zc = unique(d1(:,6));		% depths

		for j=1:length(zc)

			ind = find(d1(:,6)==zc(j));	% indices of depth level j

			if size(ind,1) > 1	% repeated

				d1(ind(1,1),2:3) = mean(d1(ind,2:3));

				d1(ind(2:end,1),:) = [];  % delete repeated lines
			end
		end

		col(:,i) = interp1(d1(:,6),d1(:,datacol),zgrid','linear','extrap');
	end

	% interpolate data between columns horizontally

	for i=1:size(V,1)
		V(i,:) = interp1(xc,col(i,:),xgrid,'linear','extrap');
	end

	% measure max(V) - we will plot all lines at this level

	maxV = max(max(V));

	% derive contours of "surface" V(X,Z)

	if isempty(procdata.plot_contour)
		cont = [];
	else
		cont = contourc(xgrid,zgrid,V,procdata.plot_contour);
	end

	% transform Z so that Z=0 shifts to surface profile and Z=max stays in place

	zmax = zgrid(end);

	for j=1:size(Z,2)

		a = 1.0 - interp1(surf_xz(:,1),surf_xz(:,2),xgrid(j),'linear','extrap')/zmax;  % stretch factor

		Z(:,j) = (Z(:,j) - zmax)*a + zmax;
	end
	
	% start plotting

	hold on

	h = surf(X,Z,V);

	shading interp

	set(h,'LineStyle','none');

	if ~isempty(value_range)
		caxis(value_range);
	end

	% draw contour lines

	clab = procdata.contour_label;		% contour plotting settings

	k = 1;

	while k < size(cont,2)
	
		n = cont(2,k);		% number of points

		xz = cont(:,(1:n)+k);	% columns of coordinates

		clab.string = num2str(cont(1,k));	% label drawn within gaps in contours	

		% transform Z in contour lines
 
		a = 1.0 - interp1(surf_xz(:,1),surf_xz(:,2),xz(1,:),'linear','extrap')/zmax;  % stretch factor

		xz(2,:) = (xz(2,:) - zmax).*a + zmax;

		% plot

		plot_line([ transpose(xz), ones(n,1)*maxV ],clab,procdata.contour_line);

		k = k + n + 1;		% next line

	end	% end plotting contours

	% draw free surface 

	line(surf_xz(:,1),surf_xz(:,2),ones(size(surf_xz,1),1)*maxV,'LineWidth',3)

	colorbar

	%axis('equal')		% this does not work in Octave
	view(0,90)
end

