%% Scale velocities in current model so that Vs becomes equal the specified value
%%
%% Parameters:
%%      z - depth level at which the scaling is applied
%%	Vs - target value for S-wave velocity at this depth
%%
%% Returns:
%%	layer - number of layer which was scaled

function layer = scale_model_Vs(z, Vs)

global procdata model modes

	% do not scale if target point is above the model

	if z < model.z0
		layer = 0;
		return
	end

	nlayers = size(model.vs,1);

	par = ones(nlayers,1);		% default scaling parameters

	ind = find(model.z >= z);	% first entry will be the index of layer to modify

	if isempty(ind)
		ind = nlayers;
	end

%mz = model.z
%z
%ind
%z0
%v0
%Vs

	layer = ind(1);

	par(layer,1) = Vs/model.vs(layer,1);

%par

  	scale_model(par,true);	% scaling relative to current model
end

