%% Modify velocities in current 'model' so that Vp and Vs are scaled by the same factor
%% and Vs is matched with a given profile
%% Scaling factors are evaluated at mid-depth of each layer.
%%
%% Parameters:
%%	ind - aray of indices of layers to which the scaling is applied
%%	Vs_poly - polynomial coefficients for the desired profile Vs(z)
%%	z - optional depth for which the weight factor is evaluated.
%%		If this parameter is given, the target velocity is modified as
%%		vs -> (vs-vs_current)*weight + vs  

function scale_model_Vs_profile(ind, Vs_poly, z)

global procdata model

%Vs_poly
%ind

	nlayers = size(model.vs,1);

	par = ones(nlayers,1);					% default scaling parameters

	v0 = polyval(Vs_poly,model.z(ind)-model.dz(ind)*0.5);	% desired Vs at middles of layers

	v = model.vs(ind,1);			% current Vs
	zl = model.z(ind) - model.dz(ind)*0.5;	% middles of layers

	if nargin >= 3		% weight given

		z1 = model.z(ind(1)) - model.dz(ind(1))*0.5;		% middle of top layer
		z2 = model.z(ind(end))- model.dz(ind(end))*0.5;		% middle of bottom layer

		if z < z1
			z = z1;
		end

		if z > z2
			z = z2;
		end

		d = 1.0/(z2-z1);	% slope of weight

		% create weight linearly tapered toward one end of depth interval
 
		a = 2.0*d*d;
		a = ( z - z2 )*a + d;
		w = ( zl - z )*a + 1.0;

% plot(w,zl,'-g')		% test plot in the same figure

		% apply weight to velocity increment

		v0 = ( v0 - v ).* w + v;
	end

	par(ind,1) = v0./v;			% scalers for Vs and Vp

  	scale_model(par,true);		% scaling relative to current model
end

