%% Scales the current model according to layer editing mode
%%
%% Parameters:
%%	layer_edit_mode - layer editing mode (1, 2, or 3)
%%	sm - handle of standard model function
%%	z - depth of point on the plot
%%	v - velocity of the point on the plot
%%
%% Returns:
%%	h - cell list of graphics handles for lines added to the current plot
%%		({} if no line added)
%% =====================================================================

function h = scale_plot_model( layer_edit_mode, sm, z, v )

global procdata model modes sett

	h = {};

	switch layer_edit_mode
		case 1			% change one layer

			layer = scale_model_Vs(z,v);

			% mark the scaled layer (to see it while doing modeling)

			vs = model.vs(layer,1);

			if layer > 1
				z = model.z(layer-1,1);
			else
				z = model.z0;
			end
 
			h{length(h)+1} = line([ vs, vs ], [ z, model.z(layer,1) ],'LineStyle','-','Marker','x','Color','g');

			drawnow

		case { 2, 3 }			% interpolate between profile

			if ~isempty(sm)
				[ ~, lst, ind ] = sm(z);

				lstmatr = [];

				for i=1:size(lst,1)
					p = lst{i,2};
					v0(i,1) = polyval(p,z);
					lstmatr = [ lstmatr; p ];
				end

				vsp = interp1(v0,lstmatr,v,'linear','extrap');	% polynomial coefficients for Vs

				if layer_edit_mode == 3
					scale_model_Vs_profile(ind, vsp, z);
				else
					scale_model_Vs_profile(ind, vsp);
				end

			  	h = horzcat(h,plot_layered_model(sm,'g',z));	% plot profile in green
			end

		case 3			% move profile ends


	end	
end

