% Function returning phase velocities of all Rayleigh-wave modes at wavenumber bfun.kx
%
% The velocity/density model should be given in global structure 'model'.
% The wavenumber and basis functions must be defined in global structure 'bfun'
%
% Returns:
%	c - column of phase velocities for all modes, in ascending order.
%		If wavenumber bfun.kx==0, zero values of c are output
%	freq - frequencies of modes
%	eigvect - matrix of eigenvectors (columns) corresponding to each mode 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ c, freq, eigvect ] = vel_rayleigh()

global bfun

%z
%kreal

% Evaluate the energy matrices for pairs of basis functions
% Basis functions are constructed so that they satisfy the boundary conditions
% on the surface and at the bottom of the model, and continuity on internal interfaces

  [M,S] = energy_forms_PSV();

  % find normalized eigenvectors and eigenvalues in ascending order:

  [eigval,eigvect] = eigen(inv(M)*S);

  % 'eigval' now contains squared frequencies of eigenmodes
  % Determine the phase velocities from them:

  omega = sqrt(eigval);

  freq = omega/2/pi;

  if abs(bfun.kx) > 1.0e-8 
  	c = omega/bfun.kx;
  else
	c = zeros(size(freq));
  end

end

